@@ -1,20 +1,15 @@
-from unittest.mock import create_autospec
-
 import pytest
 
-import smarttub
 from smarttub import SpaReminder
 
 pytestmark = pytest.mark.asyncio
 
 
 @pytest.fixture
-def reminders(mock_api):
-    spa = create_autospec(smarttub.Spa, instance=True)
-    spa.request = mock_api.request
+def reminders(mock_spa):
     reminders = [
         SpaReminder(
-            spa,
+            mock_spa,
             **{
                 "id": "WATER",
                 "lastUpdated": "2021-03-04T08:00:45.330Z",
@@ -28,15 +23,16 @@ def reminders(mock_api):
     return reminders
 
 
-async def test_reminders(reminders, mock_api):
+async def test_reminders(mock_spa, reminders):
     reminder = reminders[0]
+    assert str(reminder)
     assert reminder.id == "WATER"
     await reminder.snooze(5)
-    mock_api.request.assert_called_with(
+    mock_spa.request.assert_called_with(
         "PATCH", "reminders/WATER", {"remainingDuration": 5}
     )
-    mock_api.reset_mock()
+    mock_spa.reset_mock()
     await reminder.reset(365)
-    mock_api.request.assert_called_with(
+    mock_spa.request.assert_called_with(
         "PATCH", "reminders/WATER", {"remainingDuration": 365, "reset": True}
     )
